@@ -164,7 +164,8 @@ class KafkaEventConsumer:
 
             logger.info(f'Found offsets for timestamp {offset_timestamp}: {partitions_with_offsets}')
 
-            consumer.assign(partitions_with_offsets)
+            # We need to commit these offsets to Kafka in order to ensure these offsets are persisted.
+            consumer.commit(offsets=partitions_with_offsets)
 
         # This is already checked at the Command level, but it's possible this loop
         # could get called some other way, so check it here too.
@@ -208,6 +209,23 @@ class KafkaEventConsumer:
                 if self._shut_down_loop:
                     break
 
+                # If offsets are set, do not consume events.
+                if offset_timestamp is not None:
+                    # This log message may be noisy when we are replaying, but hopefully we only see it
+                    # once every 30 seconds.
+                    logger.info("Offsets are being reset. Sleeping instead of consuming events.")
+
+                    # We are calling poll here because we believe the offsets will not be set
+                    # correctly until poll is called, despite the offsets being reset in a different call.
+                    # This is because we don't believe that the partitions for the current consumer are assigned
+                    # until the first poll happens. Because we are not trying to consume any messages in this mode,
+                    # we are deliberately calling poll without processing the message it returns
+                    # or commiting the new offset.
+                    self.consumer.poll(timeout=CONSUMER_POLL_TIMEOUT)
+
+                    time.sleep(30)
+                    continue
+
                 # Detect probably-broken consumer and exit with error.
                 if CONSECUTIVE_ERRORS_LIMIT and consecutive_errors >= CONSECUTIVE_ERRORS_LIMIT:
                     raise Exception(f"Too many consecutive errors, exiting ({consecutive_errors} in a row)")
